Skip to content

Instantly share code, notes, and snippets.

@i8degrees
Last active December 26, 2015 23:59
Show Gist options
  • Select an option

  • Save i8degrees/7234958 to your computer and use it in GitHub Desktop.

Select an option

Save i8degrees/7234958 to your computer and use it in GitHub Desktop.
Fix compile of mplayer brew formula on OS X Mavericks v10.9
diff --git i/Library/Formula/mplayer.rb w/Library/Formula/mplayer.rb
index 369b640..f7a1fa0 100644
--- i/Library/Formula/mplayer.rb
+++ w/Library/Formula/mplayer.rb
@@ -28,9 +28,18 @@ class Mplayer < Formula
end unless MacOS.prefer_64_bit?
def patches
- # When building SVN, configure prompts the user to pull FFmpeg from git.
- # Don't do that.
- DATA if build.head?
+ patches = Array.new
+
+ if build.head?
+ # When building SVN, configure prompts the user to pull FFmpeg from git.
+ # Don't do that.
+ patches.push "https://gist.github.com/anonymous/7234266/raw/"
+ end
+
+ if MacOS.version >= :mavericks
+ # Fix compiling of brew's mplayer formula on OS X mavericks v10.9
+ patches.push "https://gist.github.com/anonymous/7234293/raw/"
+ end
end
def install
@@ -70,18 +79,3 @@ class Mplayer < Formula
system "#{bin}/mplayer", "-ao", "null", "/System/Library/Sounds/Glass.aiff"
end
end
-
-__END__
-diff --git a/configure b/configure
-index a1fba5f..5deaa80 100755
---- a/configure
-+++ b/configure
-@@ -49,8 +49,6 @@ if test -e ffmpeg/mp_auto_pull ; then
- fi
-
- if ! test -e ffmpeg ; then
-- echo "No FFmpeg checkout, press enter to download one with git or CTRL+C to abort"
-- read tmp
- if ! git clone --depth 1 git://source.ffmpeg.org/ffmpeg.git ffmpeg ; then
- rm -rf ffmpeg
- echo "Failed to get a FFmpeg checkout"
Sign up for free to join this conversation on GitHub. Already have an account? Sign in to comment